==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PriorityLevelConfigurationBuilder extends PriorityLevelConfigurationFluentImpl<PriorityLevelConfigurationBuilder> implements VisitableBuilder<PriorityLevelConfiguration,PriorityLevelConfigurationBuilder>{
  public PriorityLevelConfigurationBuilder() {
    this(false);
  }
  public PriorityLevelConfigurationBuilder(Boolean validationEnabled) {
    this(new PriorityLevelConfiguration(), validationEnabled);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PriorityLevelConfiguration(), validationEnabled);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,PriorityLevelConfiguration instance) {
    this(fluent, instance, false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,PriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfiguration instance) {
    this(instance,false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PriorityLevelConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public PriorityLevelConfiguration build() {
    PriorityLevelConfiguration buildable = new PriorityLevelConfiguration(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-flowcontrol-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PriorityLevelConfigurationBuilder extends PriorityLevelConfigurationFluent<PriorityLevelConfigurationBuilder> implements VisitableBuilder<PriorityLevelConfiguration,PriorityLevelConfigurationBuilder>{
  public PriorityLevelConfigurationBuilder() {
    this(false);
  }
  public PriorityLevelConfigurationBuilder(Boolean validationEnabled) {
    this(new PriorityLevelConfiguration(), validationEnabled);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PriorityLevelConfiguration(), validationEnabled);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,PriorityLevelConfiguration instance) {
    this(fluent, instance, false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfigurationFluent<?> fluent,PriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PriorityLevelConfiguration());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfiguration instance) {
    this(instance,false);
  }
  public PriorityLevelConfigurationBuilder(PriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PriorityLevelConfiguration());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PriorityLevelConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public PriorityLevelConfiguration build() {
    PriorityLevelConfiguration buildable = new PriorityLevelConfiguration(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
